@@ -1,12 +1,12 @@
 
 --
--- lua-TestMore : <http://fperrad.github.com/lua-TestMore/>
+-- lua-TestMore : <https://fperrad.frama.io/lua-TestMore/>
 --
 
-local tconcat = require 'table'.concat
+local tconcat = table.concat
 local setmetatable = setmetatable
 
-_ENV = nil
+local _ENV = nil
 local m = {}
 
 function m.new (_type)
@@ -57,7 +57,7 @@ end
 
 return m
 --
--- Copyright (c) 2009-2015 Francois Perrad
+-- Copyright (c) 2009-2021 Francois Perrad
 --
 -- This library is licensed under the terms of the MIT/X11 license,
 -- like Lua itself.
